@@ -13,12 +13,14 @@
 #' @param keep_tex Keep the intermediate tex file used in the conversion to PDF
 #' @param latex_engine LaTeX engine for producing PDF output. Options are
 #'   "pdflatex", "lualatex", and "xelatex".
+#' @param citation_package The LaTeX package to process citations, \code{natbib}
+#'   or \code{biblatex}.
 #' @param template Pandoc template to use for rendering. Pass "default" to use
 #'   the rmarkdown package default template; pass \code{NULL} to use pandoc's
 #'   built-in template; pass a path to use a custom template that you've
 #'   created.  See the documentation on
-#'   \href{http://johnmacfarlane.net/pandoc/demo/example9/templates.html}{pandoc
-#'   templates} for more details.
+#'   \href{http://pandoc.org/README.html}{pandoc online documentation}
+#'   for details on creating custom templates.
 #'
 #' @return R Markdown output format to pass to \code{\link{render}}
 #'
@@ -90,6 +92,7 @@ pdf_document <- function(toc = FALSE,
                          template = "default",
                          keep_tex = FALSE,
                          latex_engine = "pdflatex",
+                         citation_package = c("natbib", "biblatex"),
                          includes = NULL,
                          md_extensions = NULL,
                          pandoc_args = NULL) {
@@ -131,9 +134,16 @@ pdf_document <- function(toc = FALSE,
   latex_engine = match.arg(latex_engine, c("pdflatex", "lualatex", "xelatex"))
   args <- c(args, pandoc_latex_engine_args(latex_engine))
 
+  # citation package
+  citation_package <- match.arg(citation_package)
+  args <- c(args, paste0("--", citation_package))
+
   # content includes
   args <- c(args, includes_to_pandoc_args(includes))
 
+  # make sure the graphics package is always loaded
+  if (identical(template, "default")) args <- c(args, "--variable", "graphics=yes")
+
   # args args
   args <- c(args, pandoc_args)
 
@@ -176,6 +186,7 @@ pdf_document <- function(toc = FALSE,
     pandoc = pandoc_options(to = "latex",
                             from = from_rmarkdown(fig_caption, md_extensions),
                             args = args,
+                            latex_engine = latex_engine,
                             keep_tex = keep_tex),
     clean_supporting = !keep_tex,
     pre_processor = pre_processor,
