@@ -13,6 +13,7 @@ tufte_handout <- function(fig_width = 4,
                           dev = 'pdf',
                           highlight = "default",
                           keep_tex = FALSE,
+                          citation_package = c("natbib", "biblatex"),
                           includes = NULL,
                           md_extensions = NULL,
                           pandoc_args = NULL) {
@@ -35,6 +36,7 @@ tufte_handout <- function(fig_width = 4,
                                     highlight = highlight,
                                     template = template,
                                     keep_tex = keep_tex,
+                                    citation_package = citation_package,
                                     latex_engine = "pdflatex",
                                     includes = includes,
                                     md_extensions = md_extensions,
